//
//  ViewController.m
//  tableViewDemo
//
//  Created by andre trosky on 21/02/13.
//  Copyright (c) 2013 andre trosky. All rights reserved.
//


//This view controller MUST provide implementations for the UITableViewDataSournce protocol.
//Namely, it must implement the following 2 methods:
//1. tableView:cellForRowAtIndexPath
//2. tableView:numberOfRowsInSection

#import "ViewController.h"
#import "SimpleTableCell.h"

@implementation ViewController
{
    //instance variables to hold data for each cell's labels.
    NSArray *tableData;
    NSArray *thumbnails;
    NSArray *prepTime;
}

- (void)viewDidLoad
{
    [super viewDidLoad];
    
	//initialize specific data each cell will use.
    tableData = [NSArray arrayWithObjects:@"Egg Benedict", @"Mushroom Risotto",
                 @"Pig spit-roast", @"goat", @"beefed up beef", @"squidles",
                 @"whale", @"crabbies", @"quack", @"Instant Noodle with Egg",
                 @"Noodle with BBQ Pork", @"Japanese Noodle with Pork",
                 @"Green Tea", @"Thai Shrimp Cake", @"Angry Birds Cake",
                 @"Ham and Cheese Panini", nil];
    
    thumbnails = [NSArray arrayWithObjects:@"egg_benedict.jpg", @"mushroom_risotto.jpg",
                  @"full_breakfast.jpg", @"hamburger.jpg", @"ham_and_egg_sandwich.jpg",
                  @"creme_brelee.jpg", @"white_chocolate_donut.jpg", @"starbucks_coffee.jpg",
                  @"vegetable_curry.jpg", @"instant_noodle_with_egg.jpg",
                  @"noodle_with_bbq_pork.jpg", @"japanese_noodle_with_pork.jpg", @"green_tea.jpg",
                  @"thai_shrimp_cake.jpg", @"angry_birds_cake.jpg", @"ham_and_cheese_panini.jpg", nil];
    
    prepTime = [NSArray arrayWithObjects:@"20min", @"30min", @"40min", @"50min",
                @"20min", @"30min", @"40min", @"50min",
                @"20min", @"30min", @"40min", @"50min",
                @"20min", @"30min", @"40min", @"50min",
                nil];
}


-(NSInteger)tableView:(UITableView *)tableView numberOfRowsInSection:(NSInteger)section {
    return [tableData count];
}


-(UITableViewCell *)tableView:(UITableView *)tableView cellForRowAtIndexPath:(NSIndexPath *)indexPath {
    // this is used as an identifier for the cells to be used in the tableView rows.
    static NSString *simpleTableIdentifier = @"SimpleTableItem";
    
    //message call returns a usable tableView cell (namely a custom one 'SimpleTableCell' type)
    //located using its identifier.
    //the 'dequeueReusuableCellWithIdentifier' message is used for optimizing memory allocation.
    //If the screen can fit 4 or 5 table cells, then with reuse you only need to have 4 or 5 table
    //cells allocated in memory even if the table has 1000 entries.
    SimpleTableCell *cell = (SimpleTableCell *) [tableView dequeueReusableCellWithIdentifier:simpleTableIdentifier];
    
    if (cell == nil) {
        //'NSBundle mainBundle' msg returns a NSBundle *  reference which contains the bundled contents
        //of the applications folder.
        //'loadNibNamed' msg is using a category which adds to the foundation framwork's NSBundle class.
        //specifically, this msg provides support for loading in nib files into the application & returns
        //an NSArray containing top-level objects in the nib file.
        NSArray *nib = [[NSBundle mainBundle] loadNibNamed:@"tableViewCustomCell" owner:self options:nil];
        
        //get the SimpleTableCell object
        cell = [nib objectAtIndex:0];
    }
    
    //add the content to the specific locations within the cell.
    //each cell gets its own data which comes from NSArray instance variables defined
    //below the @implementation directive in this file.
    cell.nameLabel.text = [tableData objectAtIndex:indexPath.row];
    cell.thumbnailImageView.image = [UIImage imageNamed:[thumbnails objectAtIndex:indexPath.row]];
    cell.prepTimeLabel.text = [prepTime objectAtIndex:indexPath.row];
    
    return cell;
}


//customize the height of each cell to accommodate for the thumnail images measuring 69x69px.
- (CGFloat)tableView:(UITableView *)tableView heightForRowAtIndexPath:(NSIndexPath *)indexPath {
    return 75;
}


- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

-(void) tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath {
    UIAlertView *messageAlert =[[UIAlertView alloc] initWithTitle:@"Row selected." message:[tableData objectAtIndex:indexPath.row] delegate:nil cancelButtonTitle:@"OK" otherButtonTitles:nil, nil];
    
    [messageAlert show];
    SimpleTableCell *cell = (SimpleTableCell *)[tableView cellForRowAtIndexPath:indexPath];
    cell.accessoryType = UITableViewCellAccessoryCheckmark;
    
    [tableView deselectRowAtIndexPath:indexPath animated:YES];

}



@end
